==> virtualenv_multipython-0.2.0.tar.gz: virtualenv_multipython-0.2.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. Changes for the *upcoming release* can be found in [News directory](https://github.com/makukha/virtualenv-multipython/tree/main/src/news.d).

> [!NOTE]
> * The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).
> * This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!-- towncrier release notes start -->

## [v0.2.0](https://github.com/makukha/virtualenv-multipython/releases/tag/v0.2.0) — 2025-01-09

### Breaking 🔥

- Support for Python 2.7, 3.5, 3.6 passed to [tox-multipython](https://github.com/makukha/tox-multipython) ([#8](https://github.com/makukha/virtualenv-multipython/issues/8)) — by @makukha in #11

### Misc

- Tests for Python 3.7+ ([#5](https://github.com/makukha/virtualenv-multipython/issues/5)) — by @makukha in #10
- Linting with [mypy](https://mypy.readthedocs.io) and [ruff](https://docs.astral.sh/ruff) ([#6](https://github.com/makukha/virtualenv-multipython/issues/6)) — by @makukha in #7

### Fixed

- Multiple issues, not detected before using `py tag` and Docker test matrix ([#5](https://github.com/makukha/virtualenv-multipython/issues/5), [#8](https://github.com/makukha/virtualenv-multipython/issues/8)) — by @makukha in #10, #11


## [v0.1.2](https://github.com/makukha/virtualenv-multipython/releases/tag/v0.1.2) — 2025-01-04

### Misc

- Fix docs and metadata — by @makukha ([#3](https://github.com/makukha/virtualenv-multipython/issues/3))


## [v0.1.1](https://github.com/makukha/virtualenv-multipython/releases/tag/v0.1.1) — 2025-01-04

### Misc

- Migrate to separate repository — by @makukha ([#1](https://github.com/makukha/virtualenv-multipython/issues/1))


## [v0.1.0](https://github.com/makukha/docsub/releases/tag/v0.1.0) — 2024-01-03

### Added 🌿

- Initial release — by @makukha ([#47](https://github.com/makukha/multipython/issues/47))

==> virtualenv_multipython-0.2.1.tar.gz: virtualenv_multipython-0.2.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. Changes for the *upcoming release* can be found in [News directory](https://github.com/makukha/virtualenv-multipython/tree/main/src/news.d).

> [!NOTE]
> * The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).
> * This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!-- towncrier release notes start -->

## [v0.2.1](https://github.com/makukha/virtualenv-multipython/releases/tag/v0.2.1) — 2025-01-09

### Fixed

- Project metadata ([#16](https://github.com/makukha/virtualenv-multipython/issues/16))


## [v0.2.0](https://github.com/makukha/virtualenv-multipython/releases/tag/v0.2.0) — 2025-01-09

### Breaking 🔥

- Support for Python 2.7, 3.5, 3.6 passed to [tox-multipython](https://github.com/makukha/tox-multipython) ([#8](https://github.com/makukha/virtualenv-multipython/issues/8)) — by @makukha in #11

### Misc

- Tests for Python 3.7+ ([#5](https://github.com/makukha/virtualenv-multipython/issues/5)) — by @makukha in #10
- Linting with [mypy](https://mypy.readthedocs.io) and [ruff](https://docs.astral.sh/ruff) ([#6](https://github.com/makukha/virtualenv-multipython/issues/6)) — by @makukha in #7

### Fixed

- Multiple issues, not detected before using `py tag` and Docker test matrix ([#5](https://github.com/makukha/virtualenv-multipython/issues/5), [#8](https://github.com/makukha/virtualenv-multipython/issues/8)) — by @makukha in #10, #11


## [v0.1.2](https://github.com/makukha/virtualenv-multipython/releases/tag/v0.1.2) — 2025-01-04

### Misc

- Fix docs and metadata — by @makukha ([#3](https://github.com/makukha/virtualenv-multipython/issues/3))


## [v0.1.1](https://github.com/makukha/virtualenv-multipython/releases/tag/v0.1.1) — 2025-01-04

### Misc

- Migrate to separate repository — by @makukha ([#1](https://github.com/makukha/virtualenv-multipython/issues/1))


## [v0.1.0](https://github.com/makukha/docsub/releases/tag/v0.1.0) — 2024-01-03

### Added 🌿

- Initial release — by @makukha ([#47](https://github.com/makukha/multipython/issues/47))
